==> telegram_client-0.5.31.tar.gz: lib/telegram_client/update_telegram_client.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

// import 'package:galaxeus_lib/extension/extension.dart';
import 'package:telegram_client/telegram_client/telegram_client_core.dart';
import 'package:telegram_client/telegram_client/telegram_client_data.dart';
import 'package:telegram_client/telegram_client/update/update.dart';

class UpdateTelegramClient {
  Map rawData;
  Map query;
  Map client_option;
  TelegramClientData telegramClientData;
  TelegramClient tg;
  UpdateTelegramClient({
    required this.rawData,
    required this.query,
    required this.client_option,
    required this.telegramClientData,
    required this.tg,
  });

  /// DOCS: https://core.telegram.org/bots/api#update
  Future<Map?> updateRaw({
    required bool is_lite,
  }) async {
    if (rawData["@type"] == "updateAuthorizationState") {
      return rawData;
    }

    if (rawData["@type"] == "updateNewCallbackQuery" ||
        rawData["@type"] == "updateNewInlineCallbackQuery") {
      return await tg.callbackQuery_toJson(
        update: rawData,
        telegramClientData: telegramClientData,
      );
    }
    if (rawData["@type"] == "updateNewInlineQuery") {
      return await tg.inlineQuery_toJson(
        update: rawData,
        telegramClientData: telegramClientData,
      );
    }
    if (rawData["@type"] == "updateNewMessage") {
      return await tg.message_toJson(
        update: rawData,
        telegramClientData: telegramClientData,
      );
    }

    return null;
  }

  /// DOCS: https://core.telegram.org/bots/api#update
  Future<Map?> get update_lite async {
    return await updateRaw(is_lite: true);
  }

  /// DOCS: https://core.telegram.org/bots/api#update
  Future<Map?> get update async {
    return await updateRaw(is_lite: false);
  }
}

==> telegram_client-0.5.35.tar.gz: lib/telegram_client/update_telegram_client.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

// import 'package:galaxeus_lib/extension/extension.dart';
import 'package:telegram_client/telegram_client/telegram_client_core.dart';
import 'package:telegram_client/telegram_client/telegram_client_data.dart';
import 'package:telegram_client/telegram_client/update/update.dart';

class UpdateMessageTelegramClient {}

class UpdateTelegramClient {
  Map rawData;
  Map query;
  Map client_option;
  TelegramClientData telegramClientData;
  TelegramClient tg;
  UpdateTelegramClient({
    required this.rawData,
    required this.query,
    required this.client_option,
    required this.telegramClientData,
    required this.tg,
  });

  /// DOCS: https://core.telegram.org/bots/api#update
  Future<Map?> updateRaw({
    required bool is_lite,
    // required bool is_skip_update_old,
  }) async {
    if (rawData["@type"] == "updateAuthorizationState") {
      return rawData;
    }

    if (rawData["@type"] == "updateNewCallbackQuery" ||
        rawData["@type"] == "updateNewInlineCallbackQuery") {
      return await tg.callbackQuery_toJson(
        update: rawData,
        telegramClientData: telegramClientData,
      );
    }
    if (rawData["@type"] == "updateNewInlineQuery") {
      return await tg.inlineQuery_toJson(
        update: rawData,
        telegramClientData: telegramClientData,
      );
    }
    if (rawData["@type"] == "updateNewMessage") {
      return await tg.message_toJson(
        update: rawData,
        telegramClientData: telegramClientData,
      );
    }

    return null;
  }

  /// DOCS: https://core.telegram.org/bots/api#update
  Future<Map?> get update_lite async {
    return await updateRaw(
      is_lite: true,
    );
  }

  /// DOCS: https://core.telegram.org/bots/api#update
  Future<Map?> get update async {
    return await updateRaw(
      is_lite: false,
    );
  }
}
